==> pegasus-merchandise-api-2.2.24-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsCustomizeVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * Created by Administrator on 2016/8/31.
 */
public class PcsCustomizeVO implements Serializable {

    private Long skuId;
    private String skuCode;
    private Integer canCustomize;
    private List<Integer> customizeTypes;
    //颜色定制
    private List<PcsCustomizeElementVO> colorElementList;
    //文字定制
    private List<PcsCustomizeElementVO> wordElementList;
    //定制图片
    private List<PcsCustomizeImageVO> customizeImageList;

    public List<PcsCustomizeImageVO> getCustomizeImageList() {
        return customizeImageList;
    }

    public void setCustomizeImageList(List<PcsCustomizeImageVO> customizeImageList) {
        this.customizeImageList = customizeImageList;
    }

    public List<PcsCustomizeElementVO> getColorElementList() {
        return colorElementList;
    }

    public void setColorElementList(List<PcsCustomizeElementVO> colorElementList) {
        this.colorElementList = colorElementList;
    }

    public List<PcsCustomizeElementVO> getWordElementList() {
        return wordElementList;
    }

    public void setWordElementList(List<PcsCustomizeElementVO> wordElementList) {
        this.wordElementList = wordElementList;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public List<Integer> getCustomizeTypes() {
        return customizeTypes;
    }

    public void setCustomizeTypes(List<Integer> customizeTypes) {
        this.customizeTypes = customizeTypes;
    }

    public Integer getCanCustomize() {
        return canCustomize;
    }

    public void setCanCustomize(Integer canCustomize) {
        this.canCustomize = canCustomize;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }
}

==> pegasus-merchandise-api-4.0.16-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsCustomizeVO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;
import java.util.List;

/**
 * Created by Administrator on 2016/8/31.
 */
public class PcsCustomizeVO implements Serializable {

    private Long skuId;
    private String skuCode;
    private Integer canCustomize;
    private List<Integer> customizeTypes;
    //颜色定制
    private List<PcsCustomizeElementVO> colorElementList;
    //文字定制
    private List<PcsCustomizeElementVO> wordElementList;
    //定制图片
    private List<PcsCustomizeImageVO> customizeImageList;

	// 复制定制的skuCodes
	private String targetSkuCodes;
	private Long operatorId;

    public List<PcsCustomizeImageVO> getCustomizeImageList() {
        return customizeImageList;
    }

    public void setCustomizeImageList(List<PcsCustomizeImageVO> customizeImageList) {
        this.customizeImageList = customizeImageList;
    }

	public String getTargetSkuCodes() {
		return targetSkuCodes;
	}

	public void setTargetSkuCodes(String targetSkuCodes) {
		this.targetSkuCodes = targetSkuCodes;
	}

	public Long getOperatorId() {
		return operatorId;
	}

	public void setOperatorId(Long operatorId) {
		this.operatorId = operatorId;
	}

	public List<PcsCustomizeElementVO> getColorElementList() {
        return colorElementList;
    }

    public void setColorElementList(List<PcsCustomizeElementVO> colorElementList) {
        this.colorElementList = colorElementList;
    }

    public List<PcsCustomizeElementVO> getWordElementList() {
        return wordElementList;
    }

    public void setWordElementList(List<PcsCustomizeElementVO> wordElementList) {
        this.wordElementList = wordElementList;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public List<Integer> getCustomizeTypes() {
        return customizeTypes;
    }

    public void setCustomizeTypes(List<Integer> customizeTypes) {
        this.customizeTypes = customizeTypes;
    }

    public Integer getCanCustomize() {
        return canCustomize;
    }

    public void setCanCustomize(Integer canCustomize) {
        this.canCustomize = canCustomize;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }
}
